@@ -119,6 +119,14 @@ def limit_scan_deprecated(**kwargs):
               help='\b\n Parameter name expression describing the internal parameterisation.'
                    '\b\n\n Example: "klambda=-10_10_0.2,k2v=1"'
                    '\b\n Refer to documentation for more information')
+@click.option('-f', '--filter', 'filter_expr', default=None, show_default=True,
+              help='\b Filter parameter points by expression.\n'
+                   '\b Example: "mass=2*,350,400,450;klambda=1.*,2.*,-1.*,-2.*"\n'
+                   '\b Refer to documentation for more information\n')
+@click.option('-e', '--exclude', 'exclude_expr', default=None, show_default=True,
+              help='\b Exclude parameter points by expression.\n'
+                   '\b Example: "mass=2*,350,400,450;klambda=1.*,2.*,-1.*,-2.*"\n'
+                   '\b Refer to documentation for more information\n')
 @click.option('--outdir', default='output', show_default=True,
               help='Output directory where cached limit files and merged limit file are saved.')
 @click.option('-o', '--outname', default='limits.json', show_default=True,
@@ -208,8 +216,8 @@ def limit_scan(**kwargs):
     """
     _kwargs = {}
     for arg_name in ["input_path", "file_expr", "param_expr", "outdir", 
-                     "outname", "cache", "save_log", "save_summary",
-                     "parallel"]:
+                     "filter_expr", "exclude_expr", "outname", "cache",
+                     "save_log", "save_summary", "parallel"]:
         _kwargs[arg_name] = kwargs.pop(arg_name)
     _kwargs['config'] = kwargs
     from quickstats.concurrent import ParameterisedAsymptoticCLs
