@@ -154,7 +154,7 @@ class AnalysisObject(AbstractObject):
     def load_snapshot(self, snapshot_name:Optional[str]=None):
         if snapshot_name is not None:
             snapshot = self.model.workspace.getSnapshot(snapshot_name)
-            if not snapshot:
+            if (not snapshot) and ('0x(nil)' in snapshot.__repr__()):
                 self.stdout.warning(f"WARNING: Snapshot \"{snapshot_name}\" does not exist.")
             else:
                 self.model.workspace.loadSnapshot(snapshot_name)
