@@ -28,7 +28,7 @@ class ExtendedMinimizer(AbstractObject):
         'scan': 0,
         'num_ee': 5,
         'do_ee_wall': 1,
-        'retry': 0,
+        'retry': 1,
         'eigen': 0,
         'reuse_minimizer': 0,
         'reuse_nll': 0,
@@ -200,6 +200,12 @@ class ExtendedMinimizer(AbstractObject):
         #    nll_command_list.Add(command)
         #return nll_command_list
         return command_dict
+    
+    def set_nll_commands(self, nll_commands:List["ROOT.RooCmdArg"]):
+        command_dict = {}
+        for command in nll_commands:
+            command_dict[command.GetName()] = command
+        self.nll_commands = command_dict
         
     def configure_nll(self, constrain=None, global_observables=None, update:bool=False, **kwargs):
         command_dict = self.construct_nll_commands(constrain=constrain, 
@@ -402,8 +408,8 @@ class ExtendedMinimizer(AbstractObject):
             _hi = hi if not math.isnan(hi) else -1.0
             v.setAsymError(_lo, _hi)
             
-            self.stdout.info('ExtendedMinimizer::minimize("{}")'.format(self.name))        
-            self.stdout.info(v)
+            self.stdout.info('ExtendedMinimizer::minimize("{}")'.format(self.name))
+            v.Print()
 
     # _____________________________________________________________________________
     # Find the value of sigma evaluated at a specified nsigma, assuming NLL -2logL is roughly parabolic in par.
