@@ -138,11 +138,11 @@ class Likelihood(AnalysisObject):
                 muhat = muhat[poi_name]
                 muhat_errlo = muhat_errlo[poi_name]
                 muhat_errhi = muhat_errhi[poi_name]
-                self.stdout.info(f"\tmu hat = {muhat:.5f}")
+                self.stdout.info("mu hat = ".rjust(15)+f"{muhat:.5f}")
             else:
                 best_fit_str = ", ".join([f"{name}={value:.5f}" for name, value in muhat.items()])
-                self.stdout.info("\tbest fit: {}".format(best_fit_str))
-            self.stdout.info(f"\tuncond NLL = {nll_uncond:.5f}")
+                self.stdout.info("best fit : ".rjust(15) + f"{best_fit_str}")
+            self.stdout.info("uncond NLL = ".rjust(15) + f"{nll_uncond:.5f}")
             fit_result['uncond_fit'] = {
                 'muhat': muhat,
                 'muhat_errlo': muhat_errlo,
@@ -155,12 +155,12 @@ class Likelihood(AnalysisObject):
             if len(pois) == 1:
                 poi_name = pois.first().GetName()
                 mu = pretty_value(poi_val[poi_name])
-                self.stdout.info("\tmu = {:.5f}".format(mu))
+                self.stdout.info("mu = ".rjust(15)+f"{mu:.5f}")
             else:
                 mu = poi_val
                 mu_str = ", ".join([f"{name}={pretty_value(value)}" for name, value in poi_val.items()])
-                self.stdout.info("\tmu: {}".format(mu_str))
-            self.stdout.info("\tcond NLL = {:.5f}".format(nll_cond))
+                self.stdout.info("mu : ".rjust(15) + f"{mu_str}")
+            self.stdout.info("cond NLL = ".rjust(15)+f"{nll_cond:.5f}")
             fit_result['cond_fit'] = {
                 'mu': mu,
                 'nll': nll_cond,
@@ -170,7 +170,7 @@ class Likelihood(AnalysisObject):
         if mode == 0:
             pnll = nll_cond - nll_uncond
             qmu  = 2*pnll
-            self.stdout.info("\tPNLL = {:.5f}".format(nll_cond - nll_uncond))
+            self.stdout.info("PNLL = ".rjust(15) + "{:.5f}".format(nll_cond - nll_uncond))
             fit_result['pnll'] = pnll
             fit_result['qmu']  = qmu
             
@@ -197,12 +197,13 @@ class Likelihood(AnalysisObject):
                 fit_result['pvalue'] = None
                 
         if mode != 3:
-            self.stdout.info("\ttime (uncond_fit, cond_fit) = {:.3f}, {:.3f}".format(fit_time_uncond, fit_time_cond))
+            self.stdout.info("time = ".rjust(15) + \
+                             "(uncond_fit) {:.3f}, (cond_fit) {:.3f}".format(fit_time_uncond, fit_time_cond))
             fit_result['total_time'] = fit_time_uncond + fit_time_cond
         else:
-            self.stdout.info(f"\tPrefit NLL = {prefit_nll:.5f}")
-            self.stdout.info(f"\tPostfit NLL = {postfit_nll:.5f}")
-            self.stdout.info("\ttime = {:.3f}".format(fit_time))
+            self.stdout.info("prefit NLL = ".rjust(18) + f"{prefit_nll:.5f}")
+            self.stdout.info("postfit NLL = ".rjust(18) + f"{postfit_nll:.5f}")
+            self.stdout.info("time = ".rjust(18) + f"{fit_time:.3f}")
             fit_result['prefit_nll'] = prefit_nll
             fit_result['postfit_nll'] = postfit_nll
             fit_result['total_time'] = fit_time
