@@ -164,7 +164,7 @@ class NuisanceParameterPull(object):
             name = rank_poi.GetName()
             value = rank_poi.getVal()
             pois_hat.append(value)
-            print('{} {}'.format(name, value))
+            print(f'\t{name} = {value}')
         
         model.workspace.saveSnapshot('tmp_snapshot', model.pdf.getParameters(model.data))
         print('INFO: Made unconditional snapshot with name tmp_snapshot')
@@ -205,13 +205,13 @@ class NuisanceParameterPull(object):
             # fix theta at the MLE value +/- prefit uncertainty and minimize again to estimate the change in the POI
             
             if constraint_type:
-                print('Evaluating effect of moving {} up by {} + {}'.format(nuip_name, nuip_hat, prefit_variation))
+                print('INFO: Evaluating effect of moving {} up by {} + {}'.format(nuip_name, nuip_hat, prefit_variation))
                 pois_nom_up, prefit_up_impact_time = NuisanceParameterPull.evaluate_impact(model, minimizer,
                                                         nuip, nuip_hat + prefit_variation, rank_pois,
                                                         new_minimizer_options,  'tmp_snapshot')
                 print('INFO: Time to find prefit up impact: {:.3f} s'.format(prefit_up_impact_time))      
                 
-                print('Evaluating effect of moving {} down by {} - {}'.format(nuip_name, nuip_hat, prefit_variation))
+                print('INFO: Evaluating effect of moving {} down by {} - {}'.format(nuip_name, nuip_hat, prefit_variation))
                 pois_nom_down, prefit_down_impact_time = NuisanceParameterPull.evaluate_impact(model, minimizer,
                                                             nuip, nuip_hat - prefit_variation, rank_pois,
                                                             new_minimizer_options,  'tmp_snapshot')
@@ -299,7 +299,7 @@ class NuisanceParameterPull(object):
             for nuis_name in nuis_list:
                 if any(fnmatch.fnmatch(nuis_name, exclude_pattern) for exclude_pattern in exclude_patterns):
                     nuis_to_exclude.append(nuis_name)
-        nuis_names = list(set(nuis_to_include) - set(nuis_to_exclude))
+        nuis_names = sorted(list(set(nuis_to_include) - set(nuis_to_exclude)))
         
         if log_level == 'INFO':
             logfile_paths = [os.path.join(outdir, '{}.log'.format(nuis_name)) for nuis_name in nuis_names]
