@@ -7,7 +7,7 @@ from itertools import repeat
 
 from quickstats import semistaticmethod
 from quickstats.components import AbstractObject, ExtendedModel
-from quickstats.components.numerics import str_encode_value
+from quickstats.maths.numerics import str_encode_value
 from quickstats.utils.common_utils import execute_multi_tasks
 from quickstats.utils.root_utils import load_macro
 from quickstats.utils.roostats_utils import process_hypotest_results, merge_toy_results
@@ -35,8 +35,7 @@ class ToyLimitCalculator(AbstractObject):
                  snapshot_name:Optional[Union[List[str], str]]=None,                 
                  verbosity:Optional[Union[int, str]]=None,
                  hypotest_options:Optional[Dict]=None,
-                 mode:str='toy',
-                 use_custom_teststat_cls:bool=True):
+                 mode:str='toy'):
         super().__init__(verbosity=verbosity)
         self.model_base = ExtendedModel(filename,
                                         data_name=data_name,
@@ -81,11 +80,7 @@ class ToyLimitCalculator(AbstractObject):
         pdf_SB = self.model_SB.GetPdf()
         globs_SB = self.model_SB.GetGlobalObservables()
         
-        if use_custom_teststat_cls:
-            self.load_extension()
-            teststat_cls = ROOT.RooStats.ProfileLikelihoodTestStatEx
-        else:
-            teststat_cls = ROOT.RooStats.ProfileLikelihoodTestStat
+        teststat_cls = ROOT.RooStats.ProfileLikelihoodTestStat
         self.plr = teststat_cls(pdf_SB)
         self.plr.SetGlobalObservables(globs_SB)
         self.plr.SetOneSided(True)
@@ -124,18 +119,7 @@ class ToyLimitCalculator(AbstractObject):
         self.eps            = eps
         self.mode           = mode
         
-        self.reset_results()
-        
-
-    @semistaticmethod
-    def load_extension(self):
-        try:
-            if not hasattr(ROOT, 'ProfileLikelihoodTestStatEx'):
-                result = load_macro('ProfileLikelihoodTestStatEx')
-                if hasattr(ROOT, 'ProfileLikelihoodTestStatEx'):
-                    self.stdout.info('INFO: Loaded extension module "ProfileLikelihoodTestStatEx"')
-        except Exception as e:
-            print(e)        
+        self.reset_results()      
         
     def reset_results(self):
         result = ROOT.RooStats.HypoTestInverterResult("result", self.poi, 0.95)
