@@ -15,13 +15,15 @@ from quickstats.utils.common_utils import batch_makedirs
 
 class ParameterisedAsymptoticCLs(ParameterisedRunner):
     def __init__(self, input_path:str, config:Optional[Dict]=None,
-                 file_expr:Optional[str]=None, param_expr:Optional[str]=None, 
+                 file_expr:Optional[str]=None, param_expr:Optional[str]=None,
+                 filter_expr:Optional[str]=None, exclude_expr:Optional[str]=None,
                  outdir:str="output", outname:str="limits.json",
                  save_summary:bool=True, cache:bool=True,
                  save_log:bool=True, parallel:int=-1,
                  verbosity:Optional[Union[int, str]]="INFO"):
         
         super().__init__(file_expr=file_expr, param_expr=param_expr,
+                         filter_expr=filter_expr, exclude_expr=exclude_expr,
                          parallel=parallel, timed=True, save_log=save_log,
                          cache=cache, verbosity=verbosity)
         
