@@ -17,12 +17,14 @@ from quickstats.maths.numerics import pretty_value
 
 class ParameterisedLikelihood(ParameterisedRunner):
     def __init__(self, input_file:str, param_expr:str,
+                 filter_expr:Optional[str]=None, exclude_expr:Optional[str]=None,
                  data_name:str="combData", config:Optional[Dict]=None,
                  outdir:str="output", outname:str="{poi_names}.json",
                  cache:bool=True, save_log:bool=True, parallel:int=-1,
                  verbosity:Optional[Union[int, str]]="INFO"):
         
         super().__init__(file_expr=None, param_expr=param_expr,
+                         filter_expr=filter_expr, exclude_expr=exclude_expr,
                          parallel=parallel, timed=True, save_log=save_log,
                          cache=cache, verbosity=verbosity)
         
