@@ -28,7 +28,7 @@ def get_all_macros():
     Note: Only macros ending in .cxx will be considered
     """
     macros_dir = os.path.join(quickstats.macro_path, 'macros')
-    macro_paths = glob.glob(os.path.join(macros_dir, "*.cxx"))
+    macro_paths = glob.glob(os.path.join(macros_dir, "*/*.cxx"))
     macros = [os.path.os.path.splitext(os.path.basename(path))[0] for path in macro_paths]
     return macros
 
