@@ -7,7 +7,7 @@ from matplotlib.ticker import MaxNLocator
 from matplotlib.lines import Line2D
 from matplotlib.patches import Polygon
 
-from quickstats.plots.template import single_frame, parse_styles, draw_atlas_label
+from quickstats.plots.template import single_frame, parse_styles
 
 def score_distribution_plot(dfs:Dict[str, pd.DataFrame], hist_options:Dict[str, Dict], 
                             data_options:Optional[Dict[str, Dict]]=None,
