@@ -1,6 +1,7 @@
 from typing import Optional, Union, Dict, List, Tuple
 from copy import deepcopy
 import re
+from cycler import cycler
 import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.transforms as transforms
@@ -8,7 +9,8 @@ from matplotlib.patches import Rectangle
 from matplotlib.lines import Line2D
 from matplotlib.ticker import (MultipleLocator, FormatStrFormatter,
                                AutoMinorLocator, ScalarFormatter,
-                               Locator, Formatter, AutoLocator)
+                               Locator, Formatter, AutoLocator,
+                               MaxNLocator)
 
 from quickstats.utils.common_utils import update_nested_dict
 
@@ -23,15 +25,6 @@ class NumericFormatter(ScalarFormatter):
 
 COLOR_PALLETE = ['#000000', '#F2385A', '#4AD9D9', '#FDC536', '#125125', '#E88EED', '#B68D40']
 
-
-PLOT_STYLES = {
-    'distributions': {
-        'marker': 'o',
-        'markersize': 1,
-        'linewidth': 1
-    }
-}
-
 TEMPLATE_STYLES = {
     'default': {
         'figure':{
@@ -56,13 +49,17 @@ TEMPLATE_STYLES = {
         },
         'xtick':{
             'format': 'numeric',
+            'locator': 'auto',
             'steps': None,
-            'prune': None
+            'prune': None,
+            'integer': False
         },
         'ytick':{
-            'format': 'numeric', 
+            'format': 'numeric',
+            'locator': 'auto',
             'steps': None,
-            'prune': None
+            'prune': None,
+            'integer': False
         },        
         'xlabel': {
             'fontsize': 22,
@@ -72,7 +69,7 @@ TEMPLATE_STYLES = {
         'ylabel': {
             'fontsize': 22,
             'loc' : 'top',
-            'labelpad': 15
+            'labelpad': 10
         },
         'text':{
             'fontsize': 20,
@@ -86,52 +83,19 @@ TEMPLATE_STYLES = {
             "markersize": 0,
             "elinewidth": 1,
             "capsize": 2,
-            "capthick": 1
+            "capthick": 1,
+            "zorder": 1
         },
         'legend':{
             "fontsize": 20
         }
-    },
-    'limit': {
-        'axis':{
-            'tick_bothsides': False
-        },
-        'errorbar': {
-            "linewidth": 1,
-            "markersize": 5,
-            "marker": 'o',
-        }
-    },
-    'limit_point':{
-        'figure':{
-            'figsize': (11.111, 10.333),
-            'dpi': 72,
-            'facecolor': "#FFFFFF"
-        },        
-        'axis':{
-            'tick_bothsides': False
-        },
-        'legend':{
-            'fontsize': 22
-        },
-        'text':{
-            'fontsize': 22
-        }
-    },
-    'teststat_dist': {
-        'legend': {
-            'fontsize': 12
-        },
-        'annotation':{
-            'fontsize': 12
-        }
     }
 }
 
 ANALYSIS_OPTIONS = {
     'default': {
         'loc': (0.05, 0.95),
-        'fontsize': 20
+        'fontsize': 25
     },
     'Run2': {
         'status': 'int', 
@@ -140,6 +104,11 @@ ANALYSIS_OPTIONS = {
     }
 }
 
+AXIS_LOCATOR_MAPS = {
+    'auto': AutoLocator,
+    'maxn': MaxNLocator
+}
+
 def parse_styles(styles:Optional[Union[Dict, str]]=None):
     default_styles = deepcopy(TEMPLATE_STYLES['default'])
     if styles is None:
@@ -166,31 +135,83 @@ def parse_analysis_label_options(options:Optional[Dict]=None):
         options = update_nested_dict(default_options, deepcopy(options))
     return options
 
+def ratio_frames(height_ratios:Tuple[int]=(3, 1), hspace:float=0.07,
+                 logx:bool=False, logy:bool=False, 
+                 styles:Optional[Union[Dict, str]]=None,
+                 analysis_label_options:Optional[Union[Dict, str]]=None,
+                 prop_cycle:Optional[List[str]]=None,
+                 figure_index:Optional[int]=None):
+    if figure_index is None:
+        plt.clf()
+    else:
+        plt.figure(figure_index)
+    styles = parse_styles(styles)
+    gridspec_kw = {
+        "height_ratios": height_ratios,
+        "hspace": hspace
+    }
+    fig, (ax1, ax2) = plt.subplots(nrows=2, ncols=1, gridspec_kw=gridspec_kw,
+                                   sharex=True, **styles['figure'])
+    
+    if logx:
+        ax1.set_xscale('log')
+        ax2.set_xscale('log')
+        
+    if logy:
+        ax1.set_yscale('log')
+        
+    format_axis_ticks(ax1, x_axis=True, y_axis=True, x_axis_styles={"labelbottom":False},
+                      xtick_styles=styles['xtick'], ytick_styles=styles['ytick'], **styles['axis'])
+    format_axis_ticks(ax2, x_axis=True, y_axis=True, xtick_styles=styles['xtick'],
+                      ytick_styles=styles['ytick'], **styles['axis'])
+    
+    if analysis_label_options is not None:
+        draw_analysis_label(ax1, dy=0.05, text_options=styles['text'], **analysis_label_options)
+        
+    if prop_cycle is not None:
+        ax1.set_prop_cycle(prop_cycle)
+    
+    return ax1, ax2
+
 def single_frame(logx:bool=False, logy:bool=False, 
                  styles:Optional[Union[Dict, str]]=None,
-                 analysis_label_options:Optional[Union[Dict, str]]=None):
-    plt.clf()
+                 analysis_label_options:Optional[Union[Dict, str]]=None,
+                 prop_cycle:Optional[List[str]]=None,
+                 figure_index:Optional[int]=None):
+    if figure_index is None:
+        plt.clf()
+    else:
+        plt.figure(figure_index)
     styles = parse_styles(styles)
     fig, ax = plt.subplots(nrows=1, ncols=1, **styles['figure'])
+    
     if logx:
         ax.set_xscale('log')
     if logy:
         ax.set_yscale('log')
+        
     format_axis_ticks(ax, x_axis=True, y_axis=True, xtick_styles=styles['xtick'],
                       ytick_styles=styles['ytick'], **styles['axis'])
-        
+    
     if analysis_label_options is not None:
-        draw_atlas_label(ax, dy=0.05, text_options=styles['text'], **analysis_label_options)
+        draw_analysis_label(ax, text_options=styles['text'], **analysis_label_options)
         
+    if prop_cycle is not None:
+        ax.set_prop_cycle(prop_cycle)
+    
     return ax
 
 
 def suggest_markersize(nbins:int):
-    if nbins <= 20:
-        return 10
-    elif (nbins > 20) and (nbins <= 200):
-        return nbins/20
-    return 1
+    bin_max  = 200
+    bin_min  = 40
+    size_max = 8
+    size_min = 2
+    if nbins <= bin_min:
+        return size_max
+    elif (nbins > bin_min) and (nbins <= bin_max):
+        return ((size_min - size_max) / (bin_max - bin_min))*(nbins - bin_min) + size_max
+    return size_min
 
 def format_axis_ticks(ax, x_axis=True, y_axis=True, major_length:int=16, minor_length:int=8,
                       spine_width:int=2, major_width:int=2, minor_width:int=1, 
@@ -230,13 +251,14 @@ def format_axis_ticks(ax, x_axis=True, y_axis=True, major_length:int=16, minor_l
                        width=minor_width, **styles)
     for axis in ['top','bottom','left','right']:
         ax.spines[axis].set_linewidth(spine_width)
-        
     set_axis_tick_styles(ax.xaxis, xtick_styles)
     set_axis_tick_styles(ax.yaxis, ytick_styles)
 
-def set_axis_tick_styles(ax, styles=None):
+def set_axis_tick_styles(ax, styles=None):   
     if styles is None:
         return None
+    if ax.get_scale() == "log":
+        return None
     fmt = styles['format']
     if fmt is not None:
         formatter = None
@@ -248,25 +270,34 @@ def set_axis_tick_styles(ax, styles=None):
         if formatter is None:
             raise ValueError(f"unsupported axis tick format {fmt}")
         ax.set_major_formatter(formatter)
-    locator = AutoLocator()
-    locator_params = {}
-    for param in ['steps', 'prune']:
-        value = styles[param]
-        if value is not None:
-            locator_params[param] = value
-    locator.set_params(**locator_params)
-    ax.set_major_locator(locator)
+        
+    locator = ax.get_major_locator()
+    
+    if isinstance(locator, (AutoLocator, MaxNLocator)):
+        new_locator = AXIS_LOCATOR_MAPS.get(styles['locator'].lower(), type(locator))()
+        try:
+            available_params = list(new_locator.default_params)
+        except:
+            available_params = ['steps', 'prune', 'integer']
+        locator_params = {}
+        for param in available_params:
+            value = styles.get(param, None)
+            if value is not None:
+                locator_params[param] = value
+        new_locator.set_params(**locator_params)
+        ax.set_major_locator(new_locator)
                 
 
-def centralize_axis(ax, which='x'):
+def centralize_axis(ax, which='x', ref_value:float=0):
     if which == 'x':
-        limits = ax.get_xlim()
-        xmax = np.max(np.abs(limits))
-        ax.set_xlim(-xmax, xmax)
+        get_lim = ax.get_xlim
+        set_lim = ax.set_xlim
     elif which == 'y':
-        limits = ax.get_ylim()
-        ymax = np.max(np.abs(limits))
-        ax.set_ylim(-ymax, ymax)
+        get_lim = ax.get_ylim
+        set_lim = ax.set_ylim    
+    limits = get_lim()
+    vmax = np.max(np.abs([ref_value - limits[0], limits[1] - ref_value]))
+    set_lim(ref_value - vmax, ref_value + vmax)
         
 def parse_transform(obj:str):
     if not obj:
@@ -325,8 +356,8 @@ def draw_text(axis, x, y, s, transform_x:str='axis',
     return xmin, xmax, ymin, ymax
 
 
-def draw_ATLAS_label(axis, loc=(0.05, 0.95), fontsize=25, extra='Internal', 
-                     transform_x='axis', transform_y='axis', 
+def _draw_analysis_label(axis, loc=(0.05, 0.95), fontsize=25, extra='Internal',
+                     colab:str='ATLAS', transform_x='axis', transform_y='axis', 
                      vertical_align='top', horizontal_align='left'):
     current_axis = plt.gca()
     plt.sca(axis)
@@ -337,7 +368,7 @@ def draw_ATLAS_label(axis, loc=(0.05, 0.95), fontsize=25, extra='Internal',
     transform = transforms.blended_transform_factory(parse_transform(transform_x), 
                                                      parse_transform(transform_y))
     x, y = loc
-    text_atlas = axis.text(x, y, 'ATLAS', fontsize=fontsize, transform=transform,
+    text_atlas = axis.text(x, y, colab, fontsize=fontsize, transform=transform,
                            horizontalalignment=horizontal_align,
                            verticalalignment=vertical_align,
                            fontproperties={"weight":"bold", "style":"italic"})
@@ -350,11 +381,12 @@ def draw_ATLAS_label(axis, loc=(0.05, 0.95), fontsize=25, extra='Internal',
     _, xmax, _, ymax = get_box_dimension(text_atlas)
     return xmin, xmax, ymin, ymax
 
-def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
-                     energy:Optional[str]=None, lumi:Optional[str]=None,
-                     extra_text:Optional[str]=None, dy:float=0.05,
-                     transform_x:str='axis', transform_y:str='axis',
-                     text_options:Optional[Dict]=None):
+def draw_analysis_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
+                        energy:Optional[str]=None, lumi:Optional[str]=None,
+                        colab:str='ATLAS', extra_text:Optional[str]=None, dy:float=0.05,
+                        transform_x:str='axis', transform_y:str='axis',
+                        text_options:Optional[Dict]=None):
+    
     if status == "final":
         status_str = ""
     elif status == "int":
@@ -368,9 +400,11 @@ def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
     else:
         status_str = status
         
-    xmin, xmax, ymin, ymax = draw_ATLAS_label(axis, loc, fontsize, extra=" "+status_str,
-                                              transform_x=transform_x,
-                                              transform_y=transform_y)
+    xmin, xmax, ymin, ymax = _draw_analysis_label(axis, loc, fontsize, 
+                                                  extra=" "+status_str,
+                                                  colab=colab,
+                                                  transform_x=transform_x,
+                                                  transform_y=transform_y)
 
     elumi_text = []
     if energy is not None:
@@ -393,41 +427,4 @@ def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
     for text in texts:
         _, _, ymin, _ = draw_text(axis, xmin, ymin - dy, text, **text_options)
         
-    return
-
-def add_collective_data(ax, data, plot_styles=None):
-    if plot_styles is None:
-        plot_styles = None
-    color_iter = iter(COLOR_PALLETE)
-    for label in data:
-        styles = plot_styles.copy()
-        x = data[label]['x']
-        y = data[label]['y']
-        nbins = len(x)
-        if 'markersize' not in styles:
-            styles['markersize'] = suggest_markersize(nbins)        
-        if 'color' not in styles:
-            styles['color'] = next(color_iter)
-        styles['label'] = label
-        ax.plot(x, y, **styles)
-
-def plot_distributions(data, xlabel='', ylabel='', 
-                       figsize=(14, 8), plot_styles=None, atlas_label=False):
-    plt.clf()
-    base_size = figsize[0]
-    fig = plt.figure(figsize=figsize)
-    ax = plt.gca()
-    styles = PLOT_STYLES['distributions'].copy()
-    if plot_styles is not None:
-        styles.update(plot_styles)
-    add_collective_data(ax, data, styles)
-    limits = ax.get_ylim()
-    ax.set_ylim(limits[0], limits[1]*1.2)
-    ax.set_xlabel(xlabel, fontsize=base_size*1.6,  labelpad=base_size*0.7)
-    ax.set_ylabel(ylabel, fontsize=base_size*1.6,  labelpad=base_size*0.7)
-    format_axis_ticks(ax, major_length=14, minor_length=7, major_width=1.3, 
-                      minor_width=1.3, labelsize=base_size*1.4)
-    if atlas_label:
-        draw_ATLAS_label(ax, fontsize=base_size*1.8)
-    ax.legend(fontsize=base_size*1.2)
-    return plt
\ No newline at end of file
+    return
\ No newline at end of file
