@@ -54,10 +54,10 @@ class UpperLimit2DPlot(AbstractPlot):
         'primary_alpha'  : 0.9,
         'secondary_alpha': 0.8,
         'curve_line_styles': {
-            'color': 'hh:darkpink' 
+            'color': 'darkred' 
         },
         'curve_fill_styles':{
-            'color': '#F2385A'
+            'color': 'hh:darkpink'
         },
         'highlight_styles': {
             'linewidth' : 0,
@@ -129,6 +129,8 @@ class UpperLimit2DPlot(AbstractPlot):
             line_styles = self.config['curve_line_styles']
         if fill_styles is None:
             fill_styles = self.config['curve_fill_styles']
+        if (data['yerrlo'] is None) and (data['yerrhi'] is None):
+            line_styles['color'] = fill_styles['color']
         handle_line = ax.plot(data['x'], data['y'], label=data['label'], **line_styles)
         handles = handle_line[0]
         if (data['yerrlo'] is not None) and (data['yerrhi'] is not None):
