@@ -155,4 +155,34 @@ def get_class_that_defined_method(meth):
                       None)
         if isinstance(cls, type):
             return cls
-    return getattr(meth, '__objclass__', None)
\ No newline at end of file
+    return getattr(meth, '__objclass__', None)
+
+def batch_makedirs(dirnames:Union[str, List[str], Dict[str, str]]):
+    if isinstance(dirnames, str):
+        batch_makedirs([dirnames])
+    elif isinstance(dirnames, list):
+        for dirname in dirnames:
+            if not os.path.exists(dirname):
+                os.makedirs(dirname)
+    elif isinstance(dirnames, dict):
+        for key in dirnames:
+            if not os.path.exists(dirnames[key]):
+                os.makedirs(dirnames[key])
+
+def set_scripts_path(scripts_path, undo=False):
+    if (scripts_path in sys.path) and (undo==True):
+        sys.path.remove(scripts_path)
+        os.environ["PYTHONPATH"].replace(scripts_path+":","")
+        
+    if (scripts_path not in sys.path) and (undo==False):
+        sys.path.insert(0, scripts_path)
+        os.environ["PYTHONPATH"] = scripts_path + ":" + os.environ.get("PYTHONPATH", "")
+        
+def is_valid_file(fname:str):
+    if not os.path.exists(fname):
+        return False
+    ext = os.path.splitext(fname)[-1]
+    if ext == ".root":
+        from quickstats.utils.root_utils import is_corrupt
+        return not is_corrupt(fname)
+    return (os.path.isfile(fname)) and (os.path.getsize(fname) > 0)
\ No newline at end of file
