@@ -186,4 +186,10 @@ def print_pdf_structure(pdf:"ROOT.RooAbsPdf", level:int=0, show_address=False):
     elif class_name == "RooProdPdf":
         pdf_list = pdf.pdfList()
         for pdf_i in pdf_list:
+            print_pdf_structure(pdf_i, level+1, show_address=show_address)
+    elif class_name == "RooRealSumPdf":
+        pdf_list = pdf.getComponents()
+        for pdf_i in pdf_list:
+            if pdf_i == pdf:
+                continue
             print_pdf_structure(pdf_i, level+1, show_address=show_address)
\ No newline at end of file
